<?php

namespace Litecms\StairSteps\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\StairSteps\Models\StairSteps;

class StairStepsPolicy
{

    /**
     * Determine if the given user can view the stair_steps.
     *
     * @param UserPolicy $user
     * @param StairSteps $stair_steps
     *
     * @return bool
     */
    public function view(UserPolicy $user, StairSteps $stair_steps)
    {
        if ($user->canDo('stair_steps.stair_steps.view') && $user->isAdmin()) {
            return true;
        }

        return $stair_steps->user_id == user_id() && $stair_steps->user_type == user_type();
    }

    /**
     * Determine if the given user can create a stair_steps.
     *
     * @param UserPolicy $user
     * @param StairSteps $stair_steps
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('stair_steps.stair_steps.create');
    }

    /**
     * Determine if the given user can update the given stair_steps.
     *
     * @param UserPolicy $user
     * @param StairSteps $stair_steps
     *
     * @return bool
     */
    public function update(UserPolicy $user, StairSteps $stair_steps)
    {
        if ($user->canDo('stair_steps.stair_steps.edit') && $user->isAdmin()) {
            return true;
        }

        return $stair_steps->user_id == user_id() && $stair_steps->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given stair_steps.
     *
     * @param UserPolicy $user
     * @param StairSteps $stair_steps
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, StairSteps $stair_steps)
    {
        return $stair_steps->user_id == user_id() && $stair_steps->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given stair_steps.
     *
     * @param UserPolicy $user
     * @param StairSteps $stair_steps
     *
     * @return bool
     */
    public function verify(UserPolicy $user, StairSteps $stair_steps)
    {
        if ($user->canDo('stair_steps.stair_steps.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given stair_steps.
     *
     * @param UserPolicy $user
     * @param StairSteps $stair_steps
     *
     * @return bool
     */
    public function approve(UserPolicy $user, StairSteps $stair_steps)
    {
        if ($user->canDo('stair_steps.stair_steps.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
